@@ -19,13 +19,19 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListDeviceEventsPaginatorName", "ListDevicesPaginatorName", "ServiceName")
+__all__ = (
+    "ListDeviceEventsPaginatorName",
+    "ListDevicesPaginatorName",
+    "ServiceName",
+    "PaginatorName",
+)
 
 
 ListDeviceEventsPaginatorName = Literal["list_device_events"]
 ListDevicesPaginatorName = Literal["list_devices"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -58,6 +64,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -294,10 +301,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -305,3 +314,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_device_events", "list_devices"]
